@@ -1,9 +1,30 @@
 package Net::Async::SPORE::Definition;
-$Net::Async::SPORE::Definition::VERSION = '0.001';
+$Net::Async::SPORE::Definition::VERSION = '0.002';
 use strict;
 use warnings;
+
+=head1 NAME
+
+Net::Async::SPORE::Definition - holds information about a SPORE definition
+
+=head1 VERSION
+
+Version 0.002
+
+=head1 DESCRIPTION
+
+No user-serviceable parts inside. See L<Net::Async::SPORE::Loader> instead.
+
+=cut
+
 use JSON::MaybeXS;
 
+=head2 new
+
+Instantiates this object.
+
+=cut
+
 sub new { my $class = shift; bless { @_ }, $class }
 
 sub _transport {
@@ -33,3 +54,13 @@ sub _request {
 }
 
 1;
+
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <cpan@perlsite.co.uk>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2012-2014. Licensed under the same terms as Perl itself.
